import sys
sys.path.insert(0, '/helpers')

import unittest
from helpers import files


class TestAllFileInDirectory(unittest.TestCase):

    def test_all_files_in_directory(self):
        file_list = files.get_all_files_in_directory('.')
        print(file_list)
        self.assertEqual(2, len(file_list))


if __name__ == '__main__':
    unittest.main()



from pathlib import Path


def get_all_files_in_directory(directory):
    '''
    Function to pull files in a directory
    :param directory: path to the directory
    :return: list of files with whole path
    '''
    dirpath = Path(directory)
    assert(dirpath.is_dir())
    file_list = []
    for x in dirpath.iterdir():
        print(x)
        if x.is_file():
            file_list.append(x)
        elif x.is_dir():
            file_list.extend(get_all_files_in_directory(x))

    return file_list
